# Citation

If you use this software for research, please cite the following publications:

* {cite}`Thornton2019-nu`
* {cite}`Thornton2014-hx`

This software was developed for the first paper.
The second paper describes a key part of this software's back end.
